<?php
namespace VXN\Express\Addon;

use Closure;
use VXN\Express;
use VXN\Express\Contact\Contact_Module;
use VXN\Express\Helper\Util;
use VXN\Express\Team_Member\Team_Member_Module;
use VXN\Express\Testi\Testi_Module;
use VXN\Express\Whatsapp\Whatsapp_Module;
use VXN\Express\WP\Shortcode\Shortcode;

/**
 * Class to run express add on plugin
 * @package VXN\Express\Addon 
 * @author Vaksin <dev@vaks.in>
 * @since 1.0.0
 */
class Plugin{

    /** @return void  */
    public static function run() {	

		add_action('vxn_express_load_modules', function() {
			define( 'VXN_EXPRESS_ADDON_DOMAIN', 'vxn-express' );
			load_plugin_textdomain( VXN_EXPRESS_DOMAIN, false, dirname( plugin_basename(VXN_EXPRESS_ADDON_PLUGIN_FILE) ) . '/languages' );
            
            Express::add_module(Util::get_instance(Contact_Module::class));
            Express::add_module(Util::get_instance(Whatsapp_Module::class));
            Express::add_module(Util::get_instance(Testi_Module::class));
            Express::add_module(Util::get_instance(Team_Member_Module::class));

			Express::add_shortcode(
                'vxn-format-idr',
                function( $attr, $content ) {
                    $content = do_shortcode($content);
                    return esc_html('Rp. ' . number_format(floatval($content),0,",","."));
                }
            );
			Express::add_shortcode(
                'vxn-breadcrumb',
                function( $attr ) {
                    $args = shortcode_atts( array(     
                        'home' => null,
                        'separator' => null,
                    ), $attr );
    
                    $home = $args['home'];
                    $separator = $args['separator'];
    
                    return Util::express_breadcrumb($home, $separator);
                }
            );            
        },1);

		add_action('vxn_express_load_modules', function() {
            Express::add_menu_page(Setup_Page_Factory::create());
        },999);

        add_action('init', function(){
            if ( ! function_exists( 'yoast_breadcrumb' ) ) {
                /**
                 * Fake yoast_breadcrumb (required by breakdance breadcrumb element)
                 *
                 * @param string $before  What to show before the breadcrumb.
                 * @param string $after   What to show after the breadcrumb.
                 * @param bool   $display Whether to display the breadcrumb (true) or return it (false).
                 *
                 * @return string
                 */
                $script = '
                function yoast_breadcrumb( $before = "", $after = "", $display = true ) {
                    return \VXN\Express\Helper\Util::express_breadcrumb();
                }
                ';
                eval($script); 
            }
        }, 99);        
    }
}